@@ -1,5 +1,5 @@
 # encoding=UTF-8
-# Copyright © 2010 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010, 2011, 2012 Jakub Wilk <jwilk@jwilk.net>
 #
 # This package is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,10 +14,12 @@ import contextlib
 import locale
 import os
 import re
+import subprocess as ipc
 import sys
 import traceback
 
 from nose.tools import *
+from nose import SkipTest
 
 try:
     locale.LC_MESSAGES
@@ -110,7 +112,10 @@ def amended_locale(**kwargs):
     try:
         for category, value in kwargs.items():
             category = getattr(locale, category)
-            locale.setlocale(category, value)
+            try:
+                locale.setlocale(category, value)
+            except locale.Error, ex:
+                raise SkipTest(ex)
         yield
     finally:
         locale.setlocale(locale.LC_ALL, old_locale)
@@ -118,4 +123,30 @@ def amended_locale(**kwargs):
 def assert_repr(self, expected):
     return assert_equal(repr(self), expected)
 
+def skip_unless_c_messages():
+    if locale.setlocale(locale.LC_MESSAGES) != 'C':
+        raise SkipTest('you need to run this test with LC_MESSAGES=C')
+    if os.getenv('LANGUAGE', '') != '':
+        raise SkipTest('you need to run this test with LANGUAGE unset')
+
+def skip_unless_translation_exists(lang):
+    messages = {}
+    langs = ['C', lang]
+    for lang in langs:
+        with amended_locale(LC_ALL=lang):
+            try:
+                open(__file__ + '/')
+            except EnvironmentError, ex:
+                messages[lang] = str(ex)
+    messages = set(messages.values())
+    assert 1 <= len(messages) <= 2
+    if len(messages) == 1:
+        raise SkipTest('libc translation not found: ' + lang)
+
+def skip_unless_command_exists(command):
+    child = ipc.Popen('command -v ' + command, shell=True, stdout=ipc.PIPE, stderr=ipc.PIPE)
+    if child.wait() == 0:
+        return
+    raise SkipTest('command not found: ' + command)
+
 # vim:ts=4 sw=4 et
